==> ruta-3.1.0-source-release.zip: ruta-3.1.0/ruta-core/src/test/java/org/apache/uima/ruta/action/Shift1Test.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.uima.ruta.action;

import org.apache.uima.cas.CAS;
import org.apache.uima.ruta.engine.Ruta;
import org.apache.uima.ruta.engine.RutaTestUtils;
import org.junit.Test;

public class Shift1Test {

  @Test
  public void test() throws Exception {

    CAS cas = RutaTestUtils.processTestScriptWithDefaultSeeder(this.getClass());

    RutaTestUtils.assertAnnotationsEquals(cas, 1, 1, "only some text<br/>");

    cas.release();
  }

  @Test
  public void testOverlapping() throws Exception {
    String text = "text 2 3 x 4";
    String script = "";
    script += "NUM+{->T1};";
    script += "T1.ct==\"3\"{-> SHIFT(T1,1,3)} SW T1;";
    CAS cas = RutaTestUtils.getCAS(text);
    Ruta.apply(cas, script);
    RutaTestUtils.assertAnnotationsEquals(cas, 1, 3, "2 3", "3 x 4", "4");
  }

}

==> ruta-3.5.0-source-release.zip: ruta-3.5.0/ruta-core/src/test/java/org/apache/uima/ruta/action/Shift1Test.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.uima.ruta.action;

import org.apache.uima.cas.CAS;
import org.apache.uima.ruta.engine.Ruta;
import org.apache.uima.ruta.engine.RutaTestUtils;
import org.junit.jupiter.api.Test;

public class Shift1Test {

  @Test
  public void test() throws Exception {

    CAS cas = RutaTestUtils.processTestScriptWithDefaultSeeder(this.getClass());

    RutaTestUtils.assertAnnotationsEquals(cas, 1, 1, "only some text<br/>");

    cas.release();
  }

  @Test
  public void testOverlapping() throws Exception {
    String text = "text 2 3 x 4";
    String script = "";
    script += "NUM+{->T1};";
    script += "T1.ct==\"3\"{-> SHIFT(T1,1,3)} SW T1;";
    CAS cas = RutaTestUtils.getCAS(text);
    Ruta.apply(cas, script);
    RutaTestUtils.assertAnnotationsEquals(cas, 1, 3, "2 3", "3 x 4", "4");
  }

}
